@@ -299,6 +299,15 @@ GType                 gck_module_get_type                     (void) G_GNUC_CONS
 GckModule*            gck_module_new                          (CK_FUNCTION_LIST_PTR funcs);
 
 GckModule*            gck_module_initialize                   (const gchar *path,
+                                                               GCancellable *cancellable,
+                                                               GError **error);
+
+void                  gck_module_initialize_async             (const gchar *path,
+                                                               GCancellable *cancellable,
+                                                               GAsyncReadyCallback callback,
+                                                               gpointer user_data);
+
+GckModule *           gck_module_initialize_finish            (GAsyncResult *result,
                                                                GError **error);
 
 gboolean              gck_module_equal                        (gconstpointer module1,
@@ -315,7 +324,15 @@ GckModuleInfo*        gck_module_get_info                     (GckModule *self);
 GList*                gck_module_get_slots                    (GckModule *self,
                                                                gboolean token_present);
 
-GList*                gck_modules_initialize_registered       (void);
+GList*                gck_modules_initialize_registered        (GCancellable *cancellable,
+                                                                GError **error);
+
+void                  gck_modules_initialize_registered_async  (GCancellable *cancellable,
+                                                                GAsyncReadyCallback callback,
+                                                                gpointer user_data);
+
+GList *               gck_modules_initialize_registered_finish (GAsyncResult *result,
+                                                                GError **error);
 
 GList*                gck_modules_get_slots                   (GList *modules,
                                                                gboolean token_present);
